ALLOWED_DOMAINS = []

IUNO_SITE_DOMAIN_NAMES = {
    DEVELOPMENT: '127.0.0.1:8000',
    STAGE: '127.0.0.1:8000', #FIXME
    PRODUCTION: '127.0.0.1:8000', #FIXME
}